@@ -5,6 +5,7 @@ use bevy::pbr::{Clusters, CubemapVisibleEntities, StandardMaterial, VisiblePoint
 use bevy::render::primitives::{CubemapFrusta, Frustum, Plane};
 use bevy::render::render_resource::{PrimitiveTopology, ShaderImport};
 use bevy::render::view::{RenderLayers, VisibleEntities};
+use bevy::text::Text2dSize;
 use bevy::{
     asset::HandleId,
     pbr::DirectionalLight,
@@ -41,12 +42,12 @@ impl_for_struct_delegate_fields!(ColorMaterial: color, texture);
 
 impl_for_struct_delegate_fields!(
     OrthographicProjection:
-    left with NumberAttributes::positive(),
-    right with NumberAttributes::positive(),
-    bottom with NumberAttributes::positive(),
-    top with NumberAttributes::positive(),
-    near with NumberAttributes::positive(),
-    far with NumberAttributes::positive(),
+    left,
+    right,
+    bottom,
+    top,
+    near,
+    far,
     window_origin,
     scaling_mode,
     scale with NumberAttributes::positive(),
@@ -281,6 +282,8 @@ impl_for_struct_delegate_fields!(bevy::sprite::Rect:
 );
 impl_for_struct_delegate_fields!(TextureAtlasSprite: color, index, flip_x, flip_y);
 
+impl_for_struct_delegate_fields!(Text2dSize: size);
+
 impl Inspectable for TextureAtlas {
     type Attributes = ();
 
