@@ -3,6 +3,7 @@ mod list;
 mod number;
 mod primitives;
 mod quat;
+mod third_party;
 mod ui;
 mod vec;
 pub(crate) mod with_context;
@@ -13,6 +14,3 @@ pub use primitives::{OptionAttributes, StringAttributes};
 pub use quat::{QuatAttributes, QuatDisplay};
 pub use vec::Vec2dAttributes;
 pub use with_context::{FilterType, TextureAttributes};
-
-#[cfg(any(feature = "rapier", feature = "rapier2d"))]
-mod rapier;
