@@ -38,7 +38,7 @@
 //! }
 //! ```
 //!
-//! The list of built-in attributes is documented [here](trait.Inspectable.html#default-attributes).
+//! The list of built-in attributes is documented [here](Inspectable#default-attributes).
 //!
 //! ## World Inspector
 //!
@@ -90,8 +90,6 @@
 //!
 //! # Features
 //! - **clipboard** (enabled by default): enables `egui`'s clipboard integratoin
-// //! - **rapier**: adds support for [bevy_rapier3d](https://docs.rs/bevy_rapier3d)
-// //! - **rapier2d**: adds support for [bevy_rapier2d](https://docs.rs/bevy_rapier2d)
 
 #[macro_use]
 mod utils;
@@ -117,7 +115,6 @@ use std::marker::PhantomData;
 
 use bevy::ecs::system::Resource;
 use bevy::prelude::{App, Mut, World};
-use egui::CtxRef;
 use utils::error_label_needs_world;
 #[doc(inline)]
 pub use world_inspector::{InspectableRegistry, WorldInspectorParams, WorldInspectorPlugin};
@@ -144,7 +141,7 @@ pub mod options {
 /// The context passed to [`Inspectable::ui`].
 pub struct Context<'a> {
     /// egui ui context
-    pub ui_ctx: Option<&'a CtxRef>,
+    pub ui_ctx: Option<&'a egui::Context>,
     /// The world is only available when not using `InspectablePlugin::shared()`
     world: Option<*mut World>,
     _world_marker: PhantomData<&'a mut ()>,
@@ -252,7 +249,7 @@ impl<'a> Context<'a> {
 
 impl<'a> Context<'a> {
     /// Create a new context with access to the world
-    pub fn new_world_access(ui_ctx: Option<&'a CtxRef>, world: &'a mut World) -> Self {
+    pub fn new_world_access(ui_ctx: Option<&'a egui::Context>, world: &'a mut World) -> Self {
         Context {
             ui_ctx,
             world: Some(world),
@@ -262,7 +259,7 @@ impl<'a> Context<'a> {
     }
 
     /// Creates a context without access to `World`
-    pub fn new_shared(ui_ctx: Option<&'a CtxRef>) -> Self {
+    pub fn new_shared(ui_ctx: Option<&'a egui::Context>) -> Self {
         Context {
             ui_ctx,
             world: None,
@@ -296,7 +293,7 @@ impl<'a> Context<'a> {
         }
     }
 
-    /// Returns the [id](struct.Context.html#structfield.id) if present, otherwise a dummy id.
+    /// Returns the [id](Context#structfield.id) if present, otherwise a dummy id.
     pub fn id(&self) -> egui::Id {
         let dummy_id = egui::Id::new(42);
         match self.id {
