@@ -6,6 +6,7 @@ use bevy::render::camera::{DepthCalculation, ScalingMode, WindowOrigin};
 use bevy::render::primitives::{CubemapFrusta, Frustum, Plane};
 use bevy::render::render_resource::PrimitiveTopology;
 use bevy::render::view::VisibleEntities;
+use bevy::text::Text2dSize;
 use bevy::utils::HashMap;
 use bevy::{pbr::AmbientLight, prelude::*};
 use bevy_egui::egui;
@@ -54,7 +55,7 @@ impl InspectableRegistry {
     /// Registers a type that doesn't need to implement [`Inspectable`](crate::Inspectable)
     pub fn register_raw<T: 'static, F>(&mut self, f: F)
     where
-        F: Fn(&mut T, &mut egui::Ui, &mut Context) -> bool + Send + Sync + 'static,
+        F: Fn(&mut T, &mut egui::Ui, &mut Context<'_>) -> bool + Send + Sync + 'static,
     {
         let type_id = TypeId::of::<T>();
         let callback = Box::new(
@@ -150,6 +151,7 @@ impl Default for InspectableRegistry {
         this.register::<Handle<Shader>>();
         this.register::<ColorMaterial>();
         this.register::<Handle<ColorMaterial>>();
+        this.register::<Text2dSize>();
 
         this.register::<ClearColor>();
         this.register::<AmbientLight>();
@@ -160,29 +162,6 @@ impl Default for InspectableRegistry {
         register!(this VerticalAlign, HorizontalAlign, TextAlignment, TextStyle, TextSection, Text);
         register!(this PositionType, Direction, FlexDirection, FlexWrap, AlignItems, AlignSelf, JustifyContent);
 
-        #[cfg(feature = "rapier")]
-        {
-            use bevy_rapier3d::prelude::*;
-            register!(this
-                RigidBodyType, RigidBodyPosition, RigidBodyVelocity, RigidBodyMassProps, RigidBodyMassPropsFlags,
-                RigidBodyForces, RigidBodyActivation, RigidBodyDamping, RigidBodyDominance, RigidBodyCcd, RigidBodyChanges,
-                ColliderType, ColliderPosition, ColliderMaterial, CoefficientCombineRule, ColliderFlags, RigidBodyHandle,
-                ActiveCollisionTypes, ActiveHooks, ActiveEvents, InteractionGroups, ColliderChanges, ColliderParent,
-                ColliderPositionSync, SharedShape, RigidBodyColliders, ColliderMassProps
-            );
-        }
-        #[cfg(feature = "rapier2d")]
-        {
-            use bevy_rapier2d::prelude::*;
-            register!(this
-                RigidBodyType, RigidBodyPosition, RigidBodyVelocity, RigidBodyMassProps, RigidBodyMassPropsFlags,
-                RigidBodyForces, RigidBodyActivation, RigidBodyDamping, RigidBodyDominance, RigidBodyCcd, RigidBodyChanges,
-                ColliderType, ColliderPosition, ColliderMaterial, CoefficientCombineRule, ColliderFlags, RigidBodyHandle,
-                ActiveCollisionTypes, ActiveHooks, ActiveEvents, InteractionGroups, ColliderChanges, ColliderParent,
-                ColliderPositionSync, SharedShape, RigidBodyColliders, ColliderMassProps
-            );
-        }
-
         this
     }
 }
